@@ -1,6 +1,5 @@
 # -*- coding: UTF-8 -*-
 #
-# V0.1.5.3
 # manque scenario et panel securité
 # manque devices -temp, batterie, humidité
 # doit marcher et a tester on/off - switch et HC 
@@ -27,10 +26,7 @@ class Domoticz(IPlugin):
 #
 #
 	def devices(self, jsonInput):
-		json_data=open('domoticz.json')
-		data = json.load(json_data)
-		res1 = data['param_dz']
-	
+			
 		if jsonInput['outcome']['entities']['wit/location']['value'] :
 			location = jsonInput['outcome']['entities']['wit/location']['value']
 		else:
@@ -43,7 +39,7 @@ class Domoticz(IPlugin):
 			bod = "pas de temperature"
 #
 		idex= location + "_" + on_off
-		for rs in res1:
+		for rs in self.configuration_plugin['param_dz']:
 			if rs['ids'] == idex :
 				rss = rs
 				bod = rss(boy)
@@ -56,10 +52,7 @@ class Domoticz(IPlugin):
 
 	
 	def switchlight(self, jsonInput):
-		json_data=open('domoticz2.json')
-		data = json.load(json_data)
-		res1 = data['param_dz']
-	#
+		
 		if jsonInput['outcome']['entities']['wit/location']['value'] :
 			location = jsonInput['outcome']['entities']['wit/location']['value']
 		else:
@@ -71,7 +64,9 @@ class Domoticz(IPlugin):
 			bod = "pas de on/off"
 #
 		idex= location + "_" + on_off
-		for rs in res1:
+		#log.msg("WAMP session data received (transport ID %s): %s" % (self._parent._transportid, payload))
+		log.msg(idex)		
+		for rs in self.configuration_plugin['param_dz']:
 			if rs['ids'] == idex :
 				rss = rs
 				bod = rss(boy)
